Revisions
---------

2026.1.8

- Improve code quality and typing.
- Drop support for Python 3.10, support Python 3.14.

2025.1.1

- Improve type hints.
- Drop support for Python 3.9, support Python 3.13.

2024.5.24

- Support NumPy 2.
- Fix docstring examples not correctly rendered on GitHub.
- Add py.typed marker.
- Drop support for Python 3.8 and numpy < 1.22 (NEP29).

2022.9.28

- Return headers as str, not bytes (breaking).
- Add type hints.
- Convert to Google style docstrings.
- Drop support for Python 3.7 and numpy < 1.19 (NEP29).

2021.6.6

- Support os.PathLike file names.
- Drop support for Python 3.6 (NEP 29).

2020.1.1

- Drop support for Python 2.7 and 3.5.

2007.x.x

- Initial release.
